Examples
========

Here's a list of examples on how to use ndpyramid.


Notebook Examples
-----------------

.. include:: notebooks-examples-gallery.txt


.. toctree::
    :maxdepth: 1
    :hidden:

    examples/geotiff
    examples/pyramid-resample
    examples/pyramid-reproject
    examples/pyramid-regrid
    examples/pyramid-create
